==> pgbackrest_2.33.orig.tar.gz: pgbackrest-release-2.33/src/common/io/client.intern.h <==
/***********************************************************************************************************************************
Io Client Interface Internal
***********************************************************************************************************************************/
#ifndef COMMON_IO_CLIENT_INTERN_H
#define COMMON_IO_CLIENT_INTERN_H

#include "common/io/client.h"

/***********************************************************************************************************************************
Interface
***********************************************************************************************************************************/
typedef struct IoClientInterface
{
    // Type used to identify the client. This is stored as a pointer to a String pointer so it can be used with an existing String
    // constant (e.g. created with STRING_EXTERN()) without needing to be copied.
    const String *const *type;

    // Client name, usually host:port or some other unique indentifier
    const String *(*name)(void *driver);

    // Open a session
    IoSession *(*open)(void *driver);

    // Driver log function
    String *(*toLog)(const void *driver);
} IoClientInterface;

/***********************************************************************************************************************************
Constructors
***********************************************************************************************************************************/
IoClient *ioClientNew(void *driver, const IoClientInterface *interface);

/***********************************************************************************************************************************
Macros for function logging
***********************************************************************************************************************************/
#define FUNCTION_LOG_IO_CLIENT_INTERFACE_TYPE                                                                                      \
    IoClientInterface *
#define FUNCTION_LOG_IO_CLIENT_INTERFACE_FORMAT(value, buffer, bufferSize)                                                         \
    objToLog(&value, "IoClientInterface", buffer, bufferSize)

#endif

==> pgbackrest_2.37.orig.tar.gz: pgbackrest-release-2.37/src/common/io/client.intern.h <==
/***********************************************************************************************************************************
Io Client Interface Internal
***********************************************************************************************************************************/
#ifndef COMMON_IO_CLIENT_INTERN_H
#define COMMON_IO_CLIENT_INTERN_H

#include "common/io/client.h"
#include "common/io/session.h"
#include "common/type/string.h"

/***********************************************************************************************************************************
Interface
***********************************************************************************************************************************/
typedef struct IoClientInterface
{
    // Type used to identify the client
    StringId type;

    // Client name, usually host:port or some other unique identifier
    const String *(*name)(void *driver);

    // Open a session
    IoSession *(*open)(void *driver);

    // Driver log function
    String *(*toLog)(const void *driver);
} IoClientInterface;

/***********************************************************************************************************************************
Constructors
***********************************************************************************************************************************/
IoClient *ioClientNew(void *driver, const IoClientInterface *interface);

/***********************************************************************************************************************************
Macros for function logging
***********************************************************************************************************************************/
#define FUNCTION_LOG_IO_CLIENT_INTERFACE_TYPE                                                                                      \
    IoClientInterface *
#define FUNCTION_LOG_IO_CLIENT_INTERFACE_FORMAT(value, buffer, bufferSize)                                                         \
    objToLog(&value, "IoClientInterface", buffer, bufferSize)

#endif
